Pulse Energy AirbrakePy
==========================
AirbrakePy provides a logging.Handler implementation that can be configured to alert Airbrake (http://airbrakeapp.com).

(c) 2012 Pulse Energy, Inc.
